{% extends 'core/base.html' %}
{% load staticfiles %}

{% block title %}Reset Password{% endblock %}

{% block content %}

  <h1>Reset Password</h1>
  <section class="form-main-wrapper password-form-container">
    <form
      action="{% url 'reset_password' %}"
      method="post"
      class="reset-password-form form-generic">
      {{ form.as_p }}
      <input type="submit" value="Reset Password" class="btn btn-primary btn-lg">
    </form>
  </section>

{% endblock %}
