# AuthBackend
This layout is just to get tests to pass.

In your app you must make sure your app containing your layout page
comes before this app in settings.py to override this dummy template.

{% block content %} {% endblock %}
